@@ -1,9 +1,9 @@
 context("Check set and get bef.options()")
 
 test_that("the right default options are set", {
-  expect_that(bef.options("url"), matches("http://befdataproduction.biow.uni-leipzig.de"))
-  expect_that(bef.options("tematres_url"), matches("http://befdataproduction.biow.uni-leipzig.de:7070/vocab/index.php"))
-  expect_that(bef.options("tematres_service_url"), matches("http://befdataproduction.biow.uni-leipzig.de:7070/vocab/services.php"))
+  expect_that(bef.options("url"), matches("http://china.befdata.biow.uni-leipzig.de"))
+  expect_that(bef.options("tematres_url"), matches("http://tematres.befdata.biow.uni-leipzig.de"))
+  expect_that(bef.options("tematres_service_url"), matches("http://tematres.befdata.biow.uni-leipzig.de/vocab/services.php"))
   expect_that(bef.options("download_dir"), matches("downloads"))
 })
 
