@@ -1,12 +1,12 @@
 # This can hold helpers maybe also some sort of factories to create a certain
 # condition for testing setting the right options. This helper needs to be
-# sourced into tests that make use of it with:
+# sourced into test files that make use of it with:
 
 # source("test.helpers.R")
 
 given_the_user_is <- function(condition = NULL) {
   if(condition == "valid") {
-    valid_credentials = "Yy2APsD87JiDbF9YBnU"
+    valid_credentials = "i9ZtE0F5qoma1EooxVM"
     bef.options(user_credentials = valid_credentials)
     return(valid_credentials)
   }
@@ -20,7 +20,7 @@ given_the_user_is <- function(condition = NULL) {
 
 given_the_portal_is <- function(environment = NULL) {
   if(environment == "development") {
-    bef.options(url = "http://befdatadevelepment.biow.uni-leipzig.de")
+    bef.options(url = "http://befdatadevelopment.biow.uni-leipzig.de")
     return("development")
   }
   if(environment == "production") {
@@ -30,3 +30,18 @@ given_the_portal_is <- function(environment = NULL) {
     warning("Valid parameters are: development and production")
   }
 }
+
+given_the_dataset_is <- function(available = NULL) {
+  if(available == TRUE) {
+    id = 1
+    return(id)
+  }
+  if(available == FALSE) {
+    id = 11230982734
+    return(id)
+  } else {
+    warning("Valid parameters are: TRUE and FALSE")
+  }
+}
+
+
